# PyDME

## Warning

**Do not use** before at least version 1.0.0. There will probably be a lot of incompatible changes in the beginning.

## Purpose

It currently only has [`dolphin-memory-engine`](https://pypi.org/project/dolphin-memory-engine/) as a dependency, but the point is to put together one big package that merges the functionality of *that* and the JIT Cache refreshing its author has implemented in a different project.